[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,196 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/devices>
#include <cuda/hierarchy>
#include <cuda/launch>
#include <cuda/std/cstddef>
#include <cuda/std/numeric>
#include <cuda/std/tuple>
#include <cuda/std/type_traits>
#include <cuda/std/utility>
#include <cuda/stream>
#include <cuda/warp>
#include <cuda/experimental/group.cuh>
#include "group_testing.cuh"
namespace
{
template <class Mapping1, class Mapping2, class Config>
__device__ void test_composite_mapping(const Mapping1& mapping1, const Mapping2& mapping2, Config config)
{
using Mapping = cudax::composite_mapping<Mapping1, Mapping2>;
// Test construction from 2 mappings.
{
cudax::composite_mapping mapping{mapping1, mapping2};
static_assert(cuda::std::is_same_v<decltype(mapping), Mapping>);
static_assert(cuda::std::is_nothrow_constructible_v<Mapping, Mapping1, Mapping2>
== (cuda::std::is_nothrow_copy_constructible_v<Mapping1>
&& cuda::std::is_nothrow_copy_constructible_v<Mapping2>) );
}
// Test get().
{
const cudax::composite_mapping mapping{mapping1, mapping2};
static_assert(cuda::std::is_same_v<decltype(mapping.get()), const cuda::std::tuple<Mapping1, Mapping2>&>);
static_assert(noexcept(mapping.get()));
const auto& mapping1_ref = cuda::std::get<0>(mapping.get());
CHECK(mapping1_ref.unit_count() == 4);
const auto& mapping2_ref = cuda::std::get<1>(mapping.get());
CHECK(mapping2_ref.unit_count(0) == 1);
CHECK(mapping2_ref.unit_count(1) == 3);
}
// Test map(...).
{
const cudax::this_warp parent_group{config};
const ThreadsInWarpMappingResult prev_mapping_result;
const cudax::composite_mapping mapping{mapping1, mapping2};
static_assert(
cudax::__group_mapping_result<decltype(mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result))>);
auto result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
using Result = decltype(result);
const auto rank_in_warp = cuda::gpu_thread.rank_as<unsigned>(parent_group);
if constexpr (Mapping1::static_unit_count() != cuda::std::dynamic_extent
&& Mapping2::static_group_count() != cuda::std::dynamic_extent)
{
static_assert(Result::static_group_count() == 16);
}
else
{
static_assert(Result::static_group_count() == cuda::std::dynamic_extent);
}
CHECK(result.group_count() == 16);
CHECK(result.group_rank() == (rank_in_warp / 4 * 2 + (rank_in_warp % 4 > 0)));
static_assert(Result::static_unit_count() == cuda::std::dynamic_extent);
CHECK(result.unit_count() == ((rank_in_warp % 4 > 0) ? 3 : 1));
CHECK(result.unit_rank() == ((rank_in_warp % 4 > 0) ? (rank_in_warp % 4 - 1) : 0));
const auto lane_mask_ref = ((rank_in_warp % 4 > 0) ? 0b1110u : 0b0001u) << ((rank_in_warp / 4) * 4);
CHECK(result.lane_mask() == cuda::device::lane_mask{lane_mask_ref});
CHECK(result.is_valid());
static_assert(Result::is_always_exhaustive());
static_assert(Result::is_always_contiguous());
}
// Test operator|.
{
auto mapping = mapping1 | mapping2;
static_assert(cuda::std::is_same_v<Mapping, decltype(mapping)>);
static_assert(noexcept(mapping1 | mapping2));
const auto& mapping1_ref = cuda::std::get<0>(mapping.get());
CHECK(mapping1_ref.unit_count() == 4);
const auto& mapping2_ref = cuda::std::get<1>(mapping.get());
CHECK(mapping2_ref.unit_count(0) == 1);
CHECK(mapping2_ref.unit_count(1) == 3);
}
{
auto mapping = cudax::composite_mapping{mapping1} | mapping2;
static_assert(cuda::std::is_same_v<Mapping, decltype(mapping)>);
static_assert(noexcept(cudax::composite_mapping{mapping1} | mapping2));
const auto& mapping1_ref = cuda::std::get<0>(mapping.get());
CHECK(mapping1_ref.unit_count() == 4);
const auto& mapping2_ref = cuda::std::get<1>(mapping.get());
CHECK(mapping2_ref.unit_count(0) == 1);
CHECK(mapping2_ref.unit_count(1) == 3);
}
{
auto mapping = mapping1 | cudax::composite_mapping{mapping2};
static_assert(cuda::std::is_same_v<Mapping, decltype(mapping)>);
static_assert(noexcept(mapping1 | cudax::composite_mapping{mapping2}));
const auto& mapping1_ref = cuda::std::get<0>(mapping.get());
CHECK(mapping1_ref.unit_count() == 4);
const auto& mapping2_ref = cuda::std::get<1>(mapping.get());
CHECK(mapping2_ref.unit_count(0) == 1);
CHECK(mapping2_ref.unit_count(1) == 3);
}
{
auto mapping = cudax::composite_mapping{mapping1} | cudax::composite_mapping{mapping2};
static_assert(cuda::std::is_same_v<Mapping, decltype(mapping)>);
static_assert(noexcept(cudax::composite_mapping{mapping1} | cudax::composite_mapping{mapping2}));
const auto& mapping1_ref = cuda::std::get<0>(mapping.get());
CHECK(mapping1_ref.unit_count() == 4);
const auto& mapping2_ref = cuda::std::get<1>(mapping.get());
CHECK(mapping2_ref.unit_count(0) == 1);
CHECK(mapping2_ref.unit_count(1) == 3);
}
}
struct TestKernel
{
template <class Config>
__device__ void operator()(const Config& config)
{
{
const cudax::group_by<4> mapping1{};
const cudax::group_as mapping2{cuda::std::integer_sequence<cuda::std::size_t, 1, 3>{}};
test_composite_mapping(mapping1, mapping2, config);
}
{
const cudax::group_by mapping1{4};
const cudax::group_as mapping2{cuda::std::integer_sequence<cuda::std::size_t, 1, 3>{}};
test_composite_mapping(mapping1, mapping2, config);
}
{
const cudax::group_by<4> mapping1{};
constexpr unsigned counts2[]{1, 3};
const cudax::group_as mapping2{counts2};
test_composite_mapping(mapping1, mapping2, config);
}
{
const cudax::group_by mapping1{4};
constexpr unsigned counts2[]{1, 3};
const cudax::group_as mapping2{counts2};
test_composite_mapping(mapping1, mapping2, config);
}
}
};
} // namespace
C2H_TEST("Composite mapping", "[group]")
{
const auto device = cuda::devices[0];
const cuda::stream stream{device};
{
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<8, 4>());
cuda::launch(stream, config, TestKernel{});
}
{
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims(dim3{8, 4}));
cuda::launch(stream, config, TestKernel{});
}
stream.sync();
}